from .colored import Colored
from .style import NormalStyle, WarnStyle

warn = Colored(WarnStyle)
normal = Colored(NormalStyle)
